@@ -1,6 +1,7 @@
 import chardet
 import re
 from copy import copy
+from typing import Union
 
 
 def remove_bidir_unicode_controls(in_str):
@@ -86,7 +87,7 @@ def dotdump(s):
     return ''.join(['.' if x < 32 or x > 126 else chr(x) for x in s])
 
 
-def escape_str(s, reversible=True, force_str=False):
+def escape_str(s, reversible=True, force_str=False) -> str:
     if isinstance(s, bytes):
         return escape_str_strict(s, reversible)
     elif not isinstance(s, str):
@@ -148,6 +149,19 @@ def unescape_str(s):
     return s.decode('string_escape')
 
 
+def truncate(data: Union[bytes, str], length: int = 100) -> str:
+    """
+    This method is a helper used to avoid cluttering output
+    :param data: The buffer that will be determined if it needs to be sliced
+    :param length: The limit of characters to the buffer
+    :return str: The potentially truncated buffer
+    """
+    string = safe_str(data)
+    if len(string) > length:
+        return string[:length] + '...'
+    return string
+
+
 class NamedConstants(object):
 
     def __init__(self, name, string_value_list):
