@@ -10,8 +10,7 @@ class Seen(odm.Model):
 
 @odm.model(index=True, store=True, description="Model of File")
 class File(odm.Model):
-
-    archive_ts = odm.Date(store=False, description="Archiving timestamp")
+    archive_ts = odm.Optional(odm.Date(store=False, description="Archiving timestamp (Deprecated)"))
     ascii = odm.Keyword(index=False, store=False,
                         description="Dotted ASCII representation of the first 64 bytes of the file")
     classification = odm.Classification(description="Classification of the file")
@@ -28,3 +27,4 @@ class File(odm.Model):
     size = odm.Integer(description="Size of the file in bytes")
     ssdeep = odm.SSDeepHash(store=False, description="SSDEEP hash of the file")
     type = odm.Keyword(copyto="__text__", description="Type of file as identified by Assemblyline")
+    from_archive = odm.Boolean(index=False, default=False, description="Was loaded from the archive")
