@@ -34,14 +34,16 @@ class DockerConfig(odm.Model):
     environment: list[EnvironmentVariable] = odm.List(odm.Compound(EnvironmentVariable), default=[],
                                                       description="Additional environemnt variables for the container")
     image: str = odm.Keyword(description="Complete name of the Docker image with tag, may include registry")
-    registry_username: Opt[str] = odm.Optional(odm.Keyword(), description="The username to use when pulling the image")
-    registry_password: Opt[str] = odm.Optional(odm.Keyword(),
+    registry_username: Opt[str] = odm.Optional(odm.Keyword(default=""),
+                                               description="The username to use when pulling the image")
+    registry_password: Opt[str] = odm.Optional(odm.Keyword(default=""),
                                                description="The password or token to use when pulling the image")
     registry_type: str = odm.Enum(values=["docker", "harbor"], default='docker',
                                   description="The type of container registry")
     ports: list[str] = odm.List(odm.Keyword(), default=[], description="What ports of container to expose?")
     ram_mb: int = odm.Integer(default=512, description="Container RAM limit")
     ram_mb_min: int = odm.Integer(default=128, description="Container RAM request")
+    service_account = odm.optional(odm.keyword(description="Service account to use for pods in kubernetes"))
 
 
 @ odm.model(index=False, store=False, description="Container's Persistent Volume Configuration")
@@ -49,6 +51,8 @@ class PersistentVolume(odm.Model):
     mount_path = odm.Keyword(description="Path into the container to mount volume")
     capacity = odm.Keyword(description="The amount of storage allocated for volume")
     storage_class = odm.Keyword(description="Storage class used to create volume")
+    access_mode = odm.Enum(default='ReadWriteOnce', values=['ReadWriteOnce', 'ReadWriteMany'],
+                           description="Access mode for volume")
 
 
 @ odm.model(index=False, store=False, description="Container's Dependency Configuration")
@@ -75,6 +79,7 @@ class UpdateSource(odm.Model):
     default_classification = odm.Classification(
         default=Classification.UNRESTRICTED,
         description="Default classification used in absence of one defined in files from source")
+    git_branch: str = odm.Optional(odm.Keyword(default=""), description="Branch to checkout from Git repository.")
 
 
 @ odm.model(index=False, store=False, description="Update Configuration for Signatures")
@@ -123,6 +128,8 @@ class Service(odm.Model):
 
     uses_tags: bool = odm.Boolean(
         default=False, description="Does this service use tags from other services for analysis?")
+    uses_tag_scores: bool = odm.Boolean(
+        default=False, description="Does this service use scores of tags from other services for analysis?")
     uses_temp_submission_data: bool = odm.Boolean(
         default=False, description="Does this service use temp data from other services for analysis?")
     uses_metadata: bool = odm.Boolean(
